pub fn decrease_balance(pool: &mut dyn GetPoolMut, amount: Uint256)Expand description
Decreases the balance of the pool by the amount specified.
pub fn decrease_balance(pool: &mut dyn GetPoolMut, amount: Uint256)Decreases the balance of the pool by the amount specified.