pub struct Pool {
pub balance: Uint256,
pub shares: Uint256,
}Expand description
This data type helps to keep track of pooling together assets between multiple accounts.
Fields
balance: Uint256Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Pool
impl<'de> Deserialize<'de> for Pool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl GetPoolMut for Pool
impl GetPoolMut for Pool
fn get_pool_mut(&mut self) -> PoolMut<'_>
Sourceimpl GetPoolRef for Pool
impl GetPoolRef for Pool
fn get_pool_ref(&self) -> PoolRef<'_>
Sourceimpl JsonSchema for Pool
impl JsonSchema for Pool
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl Copy for Pool
impl StructuralPartialEq for Pool