pub struct PoolAccount {
pub principal: Uint256,
pub shares: Uint256,
}Fields
principal: Uint256Trait Implementations
Sourceimpl Clone for PoolAccount
impl Clone for PoolAccount
Sourcefn clone(&self) -> PoolAccount
fn clone(&self) -> PoolAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PoolAccount
impl Debug for PoolAccount
Sourceimpl Default for PoolAccount
impl Default for PoolAccount
Sourcefn default() -> PoolAccount
fn default() -> PoolAccount
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PoolAccount
impl<'de> Deserialize<'de> for PoolAccount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PoolAccount
impl JsonSchema for PoolAccount
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PoolAccount
impl PartialEq for PoolAccount
Sourceimpl Serialize for PoolAccount
impl Serialize for PoolAccount
Sourceimpl Zeroed for PoolAccount
impl Zeroed for PoolAccount
impl Copy for PoolAccount
impl StructuralPartialEq for PoolAccount