QueryCache

Struct QueryCache 

pub struct QueryCache<'s, 'k, K, V>
where for<'a> &'a K: Debug + PartialEq + Eq + PrimaryKey<'a>, K: Clone + Debug + PartialEq + Eq, V: Clone + Serialize + DeserializeOwned,
{ /* private fields */ }
A cache which stores values in memory to avoid repeated disk reads/writes. Values are accessed through a raw query to another contracts storage.

Implementations

Source

impl<'s, 'k, K, V> QueryCache<'s, 'k, K, V>
where for<'a> &'a K: Debug + PartialEq + Eq + PrimaryKey<'a>, K: Clone + Debug + PartialEq + Eq, V: Clone + Serialize + DeserializeOwned,

pub fn new(storage: Map<'s, &'k K, V>, addr: Addr) -> Self