pub struct QueryCache<'s, 'k, K, V>where
for<'a> &'a K: Debug + PartialEq + Eq + PrimaryKey<'a>,
K: Clone + Debug + PartialEq + Eq,
V: Clone + Serialize + DeserializeOwned,{ /* private fields */ }Expand description
A cache which stores values in memory to avoid repeated disk reads/writes. Values are accessed through a raw query to another contracts storage.
Implementations